==> faxtomail-persistence-1.0-sources.jar: com/franciaflex/faxtomail/persistence/entities/MailFolderImpl.java <==
package com.franciaflex.faxtomail.persistence.entities;

/*
 * #%L
 * FaxToMail :: Persistence
 * $Id: MailFolderImpl.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-persistence/src/main/java/com/franciaflex/faxtomail/persistence/entities/MailFolderImpl.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

/**
 * @author Kevin Morin (Code Lutin)
 * @since x.x
 */
public class MailFolderImpl extends MailFolderAbstract {

    protected transient boolean folderReadable;
    protected transient boolean folderWritable;
    protected transient boolean folderMoveable;

    @Override
    public boolean isFolderReadable() {
        return folderReadable;
    }

    @Override
    public void setFolderReadable(boolean folderReadable) {
        this.folderReadable = folderReadable;
    }

    @Override
    public boolean isFolderWritable() {
        return folderWritable;
    }

    @Override
    public void setFolderWritable(boolean folderWritable) {
        this.folderWritable = folderWritable;
    }

    @Override
    public void setFolderMoveable(boolean moveable) {
       this.folderMoveable = moveable;
    }
    
    @Override
    public boolean isFolderMoveable() {
        return folderMoveable;
    }
}

==> faxtomail-persistence-2.0.2-sources.jar: com/franciaflex/faxtomail/persistence/entities/MailFolderImpl.java <==
package com.franciaflex.faxtomail.persistence.entities;

/*
 * #%L
 * FaxToMail :: Persistence
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

/**
 * @author Kevin Morin (Code Lutin)
 * @since x.x
 */
public class MailFolderImpl extends MailFolderAbstract {

    protected transient boolean folderReadable;
    protected transient boolean folderWritable;
    protected transient boolean folderMoveable;

    @Override
    public boolean isFolderReadable() {
        return folderReadable;
    }

    @Override
    public void setFolderReadable(boolean folderReadable) {
        this.folderReadable = folderReadable;
    }

    @Override
    public boolean isFolderWritable() {
        return folderWritable;
    }

    @Override
    public void setFolderWritable(boolean folderWritable) {
        this.folderWritable = folderWritable;
    }

    @Override
    public void setFolderMoveable(boolean moveable) {
       this.folderMoveable = moveable;
    }
    
    @Override
    public boolean isFolderMoveable() {
        return folderMoveable;
    }
}
